@@ -7,8 +7,12 @@
 #undef SUSPEND_COMMAND
 #undef ENABLE_IPV6
 #undef ENABLE_NLS
+#undef ALWAYS_RESTART_SERVER
+#undef GDM_USER_PATH
+#undef GDM_RBAC_SYSCMD_KEYS
 #undef HAVE_ADT
 #undef HAVE_CATGETS
+#undef HAVE_CHKAUTHATTR
 #undef HAVE_CHPASS
 #undef HAVE_CLEARENV
 #undef HAVE_CRYPT
@@ -38,8 +42,9 @@
 #undef HAVE_XINPUT
 #undef X_SERVER
 #undef X_SERVER_PATH
-#undef X_XNEST_PATH
+#undef X_XNEST_CMD
 #undef X_XNEST_CONFIG_OPTIONS
+#undef X_XNEST_UNSCALED_FONTPATH
 #undef X_CONFIG_OPTIONS
 #undef X_PATH
 #undef XSESSION_SHELL
