@@ -21,7 +21,6 @@
 #include "config.h"
 
 #include <glib/gi18n.h>
-#include <syslog.h>
 #include <signal.h>
 #include <sys/wait.h>
 #include <sys/types.h>
@@ -35,22 +34,20 @@
 #include "display.h"
 #include "slave.h"
 #include "misc.h"
-#include "xdmcp.h"
 #include "choose.h"
 #include "auth.h"
 #include "gdm-net.h"
-#include "gdmconfig.h"
+
+#include "gdm-common.h"
+#include "gdm-log.h"
+#include "gdm-daemon-config.h"
 
 /* External vars */
-extern gint xdmcp_sessions;
-extern gint flexi_servers;
-extern gint xdmcp_pending;
-extern gboolean gdm_in_final_cleanup;
-extern GSList *displays;
 extern GdmConnection *fifoconn;
 extern GdmConnection *pipeconn;
 extern GdmConnection *unixconn;
 extern int slave_fifo_pipe_fd; /* the slavepipe (like fifo) connection, this is the write end */
+extern gint flexi_servers;
 
 static gboolean
 gdm_display_check_loop (GdmDisplay *disp)
@@ -203,7 +200,7 @@ wait_again:
 		    /* rekill the slave to tell it to
 		       hurry up and die if we're getting
 		       killed ourselves */
-		    if ((gdm_signal_terminthup_was_notified ()) ||
+		    if ((gdm_daemon_config_signal_terminthup_was_notified ()) ||
 			(t + 10 <= time (NULL))) {
 			    gdm_debug ("whack_old_slave: GOT ANOTHER SIGTERM (or it was 10 secs already), killing slave again with SIGKILL");
 			    t = time (NULL);
@@ -274,6 +271,8 @@ gdm_display_manage (GdmDisplay *d)
 
     d->managetime = time (NULL);
 
+    g_debug ("Forking slave process");
+
     /* Fork slave process */
     pid = d->slavepid = fork ();
 
@@ -293,10 +292,6 @@ gdm_display_manage (GdmDisplay *d)
 
 	d->slavepid = getpid ();
 
-	/* Close XDMCP fd in slave process */
-	if (gdm_get_value_bool (GDM_KEY_XDMCP))
-	    gdm_xdmcp_close ();
-
 	gdm_connection_close (fifoconn);
 	fifoconn = NULL;
 	gdm_connection_close (pipeconn);
@@ -304,7 +299,7 @@ gdm_display_manage (GdmDisplay *d)
 	gdm_connection_close (unixconn);
 	unixconn = NULL;
 
-	closelog ();
+	gdm_log_shutdown ();
 
 	/* Close everything */
 	gdm_close_all_descriptors (0 /* from */, fds[0] /* except */, slave_fifo_pipe_fd /* except2 */);
@@ -315,7 +310,7 @@ gdm_display_manage (GdmDisplay *d)
 	gdm_open_dev_null (O_RDWR); /* open stdout - fd 1 */
 	gdm_open_dev_null (O_RDWR); /* open stderr - fd 2 */
 
-	openlog ("gdm", LOG_PID, LOG_DAEMON);
+	gdm_log_init ();
 
 	d->slave_notify_fd = fds[0];
 
@@ -396,6 +391,7 @@ gdm_display_unmanage (GdmDisplay *d)
     gdm_debug ("gdm_display_unmanage: Display stopped");
 }
 
+
 /* Why recount?  It's just a lot more robust this way and
    gets around those nasty one off errors and races.  And we never
    have so many displays that this would get too slow. */
@@ -403,19 +399,15 @@ static void
 count_session_limits (void)
 {
 	GSList *li;
+	GSList *displays;
+
+	displays = gdm_daemon_config_get_display_list ();
 
-	xdmcp_sessions = 0;
-	xdmcp_pending = 0;
 	flexi_servers = 0;
 
 	for (li = displays; li != NULL; li = li->next) {
 		GdmDisplay *d = li->data;
-		if (SERVER_IS_XDMCP (d)) {
-			if (d->dispstat == XDMCP_MANAGED)
-				xdmcp_sessions++;
-			else if (d->dispstat == XDMCP_PENDING)
-				xdmcp_pending++;
-		}
+
 		if (SERVER_IS_FLEXI (d)) {
 			flexi_servers++;
 		}
@@ -432,6 +424,7 @@ count_session_limits (void)
 void
 gdm_display_dispose (GdmDisplay *d)
 {
+
     if (d == NULL)
 	return;
 
@@ -455,7 +448,7 @@ gdm_display_dispose (GdmDisplay *d)
 	    d->master_notify_fd = -1;
     }
 
-    displays = g_slist_remove (displays, d);
+    gdm_daemon_config_display_list_remove (d);
 
     d->dispstat = DISPLAY_DEAD;
     d->type = -1;
@@ -575,6 +568,9 @@ GdmDisplay *
 gdm_display_lookup (pid_t pid)
 {
     GSList *li;
+    GSList *displays;
+
+    displays = gdm_daemon_config_get_display_list ();
 
     /* Find slave in display list */
     for (li = displays; li != NULL; li = li->next) {
