@@ -1,4 +1,6 @@
-/* GDM - The Gnome Display Manager
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * GDM - The Gnome Display Manager
  * Copyright (C) 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This file Copyright (c) 2003 George Lebl
@@ -22,14 +24,13 @@
 #ifndef GDM_COMMON_H
 #define GDM_COMMON_H
 
-#include <gtk/gtk.h> 
+#include <gtk/gtk.h>
 
 #include "misc.h"
 
 /* Handle error messages */
-void      gdm_common_openlog                (const char *ident,
-                                             int logopt,
-                                             int facility);
+void      gdm_common_log_init               (void);
+void      gdm_common_log_set_debug          (gboolean enable);
 void	  gdm_common_fail_exit		    (const gchar *format, ...)
 					     G_GNUC_PRINTF (1, 2);
 void	  gdm_common_fail_greeter	    (const gchar *format, ...)
@@ -58,6 +59,7 @@ GdkPixbuf *gdm_common_get_face              (const char *filename,
                                              guint       max_width,
                                              guint       max_height);
 
+gchar*	  gdm_common_text_to_escaped_utf8   (const char *text);
 gchar*	  gdm_common_get_config_file	    (void);
 gchar*	  gdm_common_get_custom_config_file (void);
 gboolean  gdm_common_select_time_format	    (void);
