@@ -26,15 +26,21 @@
 #include <unistd.h>
 
 #include "gdm.h"
+#include "gdmwm.h"
 #include "gdmconfig.h"
 #include "gdmcommon.h"
 #include "misc.h"
 
+#include "gdm-common.h"
+#include "gdm-daemon-config-keys.h"
+
 #include "greeter_item.h"
 #include "greeter_configuration.h"
 
 extern gboolean GdmHaltFound;
 extern gboolean GdmRebootFound;
+extern gboolean GdmCustomCmdFound;
+extern gboolean *GdmCustomCmdsFound;
 extern gboolean GdmSuspendFound;
 extern gboolean GdmConfiguratorFound;
 
@@ -73,7 +79,8 @@ greeter_item_info_new (GreeterItemInfo *parent,
 
   info->show_modes = GREETER_ITEM_SHOW_EVERYWHERE;
 
-  info->button = FALSE;
+  info->canvasbutton = FALSE;
+  info->gtkbutton    = FALSE;
 
   if (GREETER_ITEM_TYPE_IS_TEXT (info))
     {
@@ -154,7 +161,8 @@ greeter_item_is_visible (GreeterItemInfo *info)
   static gboolean checked = FALSE;
   static gboolean GDM_IS_LOCAL = FALSE;
   static gboolean GDM_FLEXI_SERVER = FALSE;
-  gboolean sysmenu = FALSE;
+  gboolean sysmenu = FALSE;	
+  gint i = 0;
 
   if ( ! checked)
     {
@@ -177,9 +185,18 @@ greeter_item_is_visible (GreeterItemInfo *info)
        ! (info->show_modes & GREETER_ITEM_SHOW_REMOTE))
     return FALSE;
 
+  if ((gdm_wm_screen.width < info->minimum_required_screen_width) ||
+      (gdm_wm_screen.height < info->minimum_required_screen_height))
+    return FALSE;
+
   sysmenu = gdm_config_get_bool (GDM_KEY_SYSTEM_MENU);
 
+ /*
+  * Disable Configuration if using accessibility (AddGtkModules) since
+  * using it with accessibility causes a hang.
+  */
   if (( ! gdm_config_get_bool (GDM_KEY_CONFIG_AVAILABLE) ||
+	gdm_config_get_bool (GDM_KEY_ADD_GTK_MODULES) ||
         ! sysmenu ||
         ! GdmConfiguratorFound) &&
       (info->show_type != NULL &&
@@ -208,8 +225,20 @@ greeter_item_is_visible (GreeterItemInfo *info)
        strcmp (info->show_type, "suspend") == 0))
 	  return FALSE;
 
+  for (i = 0; i < GDM_CUSTOM_COMMAND_MAX; i++) {      
+      gchar * key_string = g_strdup_printf ("custom_cmd%d", i);
+      if (( ! sysmenu || ! GdmCustomCmdsFound[i]) &&
+          (info->show_type != NULL &&
+           strcmp (info->show_type, key_string) == 0)) {
+	      g_free (key_string);
+	      return FALSE;
+      }
+      g_free (key_string);
+  }
+
   if (( ! gdm_config_get_bool (GDM_KEY_TIMED_LOGIN_ENABLE) ||
-          ve_string_empty (gdm_config_get_string (GDM_KEY_TIMED_LOGIN))) &&
+          ve_string_empty (gdm_config_get_string (GDM_KEY_TIMED_LOGIN)) ||
+          NULL == g_getenv("GDM_TIMED_LOGIN_OK")) &&
       (info->show_type != NULL &&
        strcmp (info->show_type, "timed") == 0))
 	  return FALSE;
